@@ -1,8 +1,8 @@
 from nlp_tools.embeddings.abc_embedding import ABCEmbedding
 from nlp_tools.embeddings.bare_embedding import BareEmbedding
-from nlp_tools.embeddings.bert_embedding import BertEmbedding
+
 from nlp_tools.embeddings.word_embedding import WordEmbedding
-from nlp_tools.embeddings.transformer_embedding import TransformerEmbedding
+
 from nlp_tools.layers import L
 from nlp_tools.logger import  logger
 
