@@ -21,7 +21,7 @@ class ABCEmbedding:
             '__class_name__': self.__class__.__name__,
             '__module__': self.__class__.__module__,
             'config': config,
-            'embed_model': json.loads(self.embed_model.to_json())
+            #'embed_model': json.loads(self.embed_model.to_json())
         }
 
     def __init__(self,
@@ -41,9 +41,10 @@ class ABCEmbedding:
         self.bert_application = bert_application
 
     def _override_load_model(self,config:Dict) -> None:
-        embed_model_json_str = json.dumps(config['embed_model'])
-        self.embed_model = tf.keras.models.model_from_json(embed_model_json_str,
-                                                           custom_objects=nlp_tools.custom_objects)
+        pass
+        # embed_model_json_str = json.dumps(config['embed_model'])
+        # self.embed_model = tf.keras.models.model_from_json(embed_model_json_str,
+        #                                                    custom_objects=nlp_tools.custom_objects)
 
 
     def build_embedding_model(self,
