@@ -3,7 +3,6 @@ from nlp_tools.layers.conditional_random_field import KConditionalRandomField
 from nlp_tools.layers.kmax_pool_layer import KMaxPoolingLayer
 from nlp_tools.layers.att_wgt_avg_layer import AttentionWeightedAverageLayer
 from nlp_tools.layers.behdanau_attention import BahdanauAttention
-#from nlp_tools.layers.pool_layer import PoolerInputLayer
 from nlp_tools.loss.r_drop_loss import RDropLoss
 
 from nlp_tools.loss import TextGenerateCrossEntropy
@@ -16,13 +15,10 @@ L.KConditionalRandomField = KConditionalRandomField
 
 
 L.TextGenerateCrossEntropy = TextGenerateCrossEntropy
-from tensorflow.keras.layers import LayerNormalization
 
-class NlpToolsLayerNormalization(LayerNormalization):
-    def __init__(self,
-               **kwargs):
-        super(NlpToolsLayerNormalization,self).__init__(**kwargs)
 
+
+from transformers import TFBertModel
 def resigter_custom_layers(custom_objects: Dict[str, Any]) -> Dict[str, Any]:
     custom_objects['KConditionalRandomField'] = KConditionalRandomField
     custom_objects['BahdanauAttention'] = BahdanauAttention
@@ -30,8 +26,8 @@ def resigter_custom_layers(custom_objects: Dict[str, Any]) -> Dict[str, Any]:
 
     custom_objects['TextGenerateCrossEntropy'] = TextGenerateCrossEntropy
     custom_objects['r_drop_loss'] = RDropLoss(loss_func=None)
-    #custom_objects['PoolerInputLayer'] = PoolerInputLayer
-    custom_objects['NlpToolsLayerNormalization'] = NlpToolsLayerNormalization
+
+    custom_objects['TFBertModel'] = TFBertModel
 
 
     return custom_objects
\ No newline at end of file
