@@ -13,7 +13,7 @@ class RDropLoss():
         """配合上述生成器的R-Drop Loss
             其实loss_kl的除以4，是为了在数量上对齐公式描述结果。
             """
-        loss_ce = self.loss_func(y_true, y_pred)  # 原来的loss
+        loss = self.loss_func(y_true, y_pred)  # 原来的loss
         loss_kl = kld(y_pred[::2], y_pred[1::2]) + kld(y_pred[1::2], y_pred[::2])
-        return loss_ce + K.mean(loss_kl) / 4 * alpha
+        return loss + K.mean(loss_kl) / 4 * alpha
 
