@@ -14,40 +14,43 @@ class ClassificationProcessor(ABCLabelProcessor):
 
     def to_dict(self) -> Dict[str, Any]:
         data = super(ClassificationProcessor, self).to_dict()
-        data['config']['multi_label'] = self.multi_label
+        data['config']['label2id'] = self.vocab2idx
         return data
 
     def __init__(self,
                  multi_label: bool = False,
+                 label2id = None,
                  **kwargs: Any) -> None:
 
         super(ClassificationProcessor, self).__init__(**kwargs)
+        self.vocab2idx = label2id
         self.multi_label = multi_label
         self.multi_label_binarizer = MultiLabelBinarizer(self.vocab2idx)
 
     def build_vocab_generator(self,
                               generators: List[CorpusGenerator]) -> None:
-        vocab2idx: Dict[str, int] = {}
-        token2count: Dict[str, int] = {}
-        for generator in generators:
-            if self.multi_label:
-                for (_, label) in tqdm.tqdm(generator.sample(), desc="Preparing classification label vocab dict"):
-                    for token in label:
-                        count = token2count.get(token, 0)
-                        token2count[token] = count + 1
-            else:
-                for _, label in tqdm.tqdm(generator.sample(), desc="Preparing classification label vocab dict"):
-                    count = token2count.get(label, 0)
-                    token2count[label] = count + 1
+        if not self.vocab2idx:
+            vocab2idx: Dict[str, int] = {}
+            token2count: Dict[str, int] = {}
+            for generator in generators:
+                if self.multi_label:
+                    for (_, label) in tqdm.tqdm(generator.sample(), desc="Preparing classification label vocab dict"):
+                        for token in label:
+                            count = token2count.get(token, 0)
+                            token2count[token] = count + 1
+                else:
+                    for _, label in tqdm.tqdm(generator.sample(), desc="Preparing classification label vocab dict"):
+                        count = token2count.get(label, 0)
+                        token2count[label] = count + 1
 
-        sorted_token2count = sorted(token2count.items(),
-                                    key=operator.itemgetter(0))
-        token2count = collections.OrderedDict(sorted_token2count)
+            sorted_token2count = sorted(token2count.items(),
+                                        key=operator.itemgetter(0))
+            token2count = collections.OrderedDict(sorted_token2count)
 
-        for token, token_count in token2count.items():
-            if token not in vocab2idx:
-                vocab2idx[token] = len(vocab2idx)
-        self.vocab2idx = vocab2idx
+            for token, token_count in token2count.items():
+                if token not in vocab2idx:
+                    vocab2idx[token] = len(vocab2idx)
+            self.vocab2idx = vocab2idx
         self.idx2vocab = dict([(v, k) for k, v in self.vocab2idx.items()])
         self.multi_label_binarizer = MultiLabelBinarizer(self.vocab2idx)
 
