@@ -8,6 +8,7 @@ from nlp_tools.generators import CorpusGenerator
 from nlp_tools.processors.abc_sentence_processor import ABCSentenceProcessor
 from nlp_tools.types import TextSamplesVar
 from nlp_tools.utils import list_utils
+import re
 
 
 class DialogueSequenceProcessor(ABCSentenceProcessor, ABC):
@@ -43,6 +44,9 @@ class DialogueSequenceProcessor(ABCSentenceProcessor, ABC):
             sub_ner_masking = []
             start_position = 0
             new_seq = []
+
+            # 每句话都是以D: 或者S:开头，代表相应的角色，现在默认删除，后面可以根据角色吧toke_type设置不同的
+            seq = [re.sub("^.{0,1}\:", "", sentence) for sentence in seq]
             for index, sub_seq in enumerate(seq):
                 if "$$" in sub_seq:
                     split_tokens = sub_seq.split("$$")
@@ -60,9 +64,11 @@ class DialogueSequenceProcessor(ABCSentenceProcessor, ABC):
                         if index == 0:
                             # 如果是第一个位置，则要加上[cls]这个特殊词的位置
                             start_entity += 1
-
-                        for i in range(start_entity, start_entity + len(self.text_tokenizer.tokenize(split_tokens[1]))):
-                            sub_ner_masking.append(i)
+                        if start_entity >= seq_length or start_entity + len(self.text_tokenizer.tokenize(split_tokens[1])) >= seq_length:
+                            sub_ner_masking.append(0)
+                        else:
+                            for i in range(start_entity, start_entity + len(self.text_tokenizer.tokenize(split_tokens[1]))):
+                                sub_ner_masking.append(i)
 
                 tokenized_seq = self.text_tokenizer.tokenize(sub_seq, max_len=seq_length, add_special_tokens=True)
                 if index != 0:
