@@ -55,18 +55,8 @@ class SequenceProcessor(ABCSentenceProcessor):
 
 
 
-        tokenids, segment_ids = [],[]
-        for seq in samples:
-            seq_tokenids,seq_segment_ids = self.text_tokenizer.encode(seq,maxlen=seq_length)
-            tokenids.append(seq_tokenids)
-            segment_ids.append(seq_segment_ids)
-
-
-        token_ids = pad_sequences(tokenids, seq_length, padding='post', truncating='post')
-        segment_ids = pad_sequences(segment_ids, seq_length, padding='post', truncating='post')
-        token_ids = np.array(token_ids)
-        segment_ids = np.array(segment_ids)
-        return token_ids, segment_ids
+        tokenizers_result = self.text_tokenizer.encode(samples, maxlen=seq_length)
+        return tokenizers_result
 
 
     def inverse_transform(self,
@@ -103,7 +93,7 @@ class SequenceProcessor(ABCSentenceProcessor):
         """
         seq_lens = []
         for gen in generators:
-            for (sentence, _) in tqdm.tqdm(gen.sample(), desc="Calculating sequence length"):
+            for (sentence, _) in tqdm.tqdm(gen, desc="Calculating sequence length"):
                 seq_lens.append(len(self.text_tokenizer.tokenize(sentence)))
         if cover_rate == 1.0:
             target_index = -1
