@@ -70,7 +70,7 @@ class ABCTaskModel(ABC):
 
 
     def to_dict(self) -> Dict[str, Any]:
-        model_json_str = self.tf_model.to_json()
+        #model_json_str = self.tf_model.to_json()
 
         save_json = {
             'tf_version': tf.__version__,
@@ -84,7 +84,7 @@ class ABCTaskModel(ABC):
                 'use_rdrop':self.use_rdrop
             },
             'label_processor': self.label_processor.to_dict(),
-            'tf_model': json.loads(model_json_str),
+            #'tf_model': json.loads(model_json_str),
             'model_node_names':self.model_node_names
         }
 
@@ -107,11 +107,15 @@ class ABCTaskModel(ABC):
         # 将inputs和outputs 节点的name保存下来
         self.model_node_names = self.get_input_and_output_names_from_model()
 
+        if(hasattr(self.text_processor.text_tokenizer,"change_model_path")):
+            self.text_processor.text_tokenizer.change_model_path(os.path.join(model_path,'text_tokenizer'))
+
         with open(os.path.join(model_path,'model_config.json'), 'w',encoding='utf-8') as f:
             f.write(json.dumps(self.to_dict(),indent=2,ensure_ascii=False))
             f.close()
 
-        tf.keras.models.save_model(self.tf_model,os.path.join(model_path,'model_weights'))
+        tf.keras.models.save_model(self.tf_model,os.path.join(model_path,'model_weights'),include_optimizer=False)
+
         logger.info('model saved to {}'.format(os.path.abspath(model_path)))
         return model_path
 
@@ -120,11 +124,16 @@ class ABCTaskModel(ABC):
         model_config_path = os.path.join(model_path,'model_config.json')
         model_config = json.loads(open(model_config_path,'r',encoding='utf-8').read())
 
+
+        if 'model_path' in model_config['text_processor']['text_tokenizer']['config']:
+            model_config['text_processor']['text_tokenizer']['config']['model_path'] = os.path.join(model_path,'text_tokenizer')
+
         model_config['config']['text_processor'] = load_data_object(model_config['text_processor'])
         model_config['config']['label_processor'] = load_data_object(model_config['label_processor'])
-        model_config['config']['embedding'] = load_data_object(model_config['embedding'])
+        #model_config['config']['embedding'] = load_data_object(model_config['embedding'])
         model = load_data_object(model_config)
         model.tf_model = tf.keras.models.load_model(os.path.join(model_path,'model_weights'),custom_objects=nlp_tools.custom_objects)
+        #model.tf_model = tf.keras.models.load_model(os.path.join(model_path, 'model_weights'))
         return model
 
 
@@ -145,11 +154,11 @@ class ABCTaskModel(ABC):
     def build_model_generator(self,generators) -> None:
 
         self.label_processor.build_vocab_generator(generators)
-        if self.train_max_sequence_length is None and self.text_processor:
-            self.train_max_sequence_length = self.text_processor.get_max_seq_length_from_corpus(generators,cover_rate=1.0)
-
-        if self.train_sequece_length_as_max_sequence_length:
-            self.max_sequence_length = self.train_sequece_length_as_max_sequence_length
+        # if self.train_max_sequence_length is None and self.text_processor:
+        #     self.train_max_sequence_length = self.text_processor.get_max_seq_length_from_corpus(generators,cover_rate=1.0)
+        #
+        # if self.train_sequece_length_as_max_sequence_length:
+        #     self.max_sequence_length = self.train_sequece_length_as_max_sequence_length
 
         self.label_processor.update_length_info(embedding_max_position=self.embedding_max_position,max_sentence_length=self.max_sequence_length)
 
@@ -173,8 +182,8 @@ class ABCTaskModel(ABC):
 
     def get_input_and_output_names_from_model(self):
         '''从模型中获取到输入和输出的node 的名称'''
-        input_names = [node.op.name for node in self.tf_model.inputs]
-        output_names = [node.op.name for node in self.tf_model.outputs]
+        input_names = [node.name for node in self.tf_model.inputs]
+        output_names = [node.name for node in self.tf_model.outputs]
         node_names_dict = {}
         node_names_dict['inputs'] = input_names
         node_names_dict['outputs'] = output_names
