@@ -23,7 +23,7 @@ class ABCSimilaryModel(ABCTaskModel,ABC):
     '''
         Abstract Similary Model
     '''
-    __task__ = 'similary'
+    __task__ = 'encoder'
 
     def to_dict(self) -> Dict:
         info = super(ABCSimilaryModel,self).to_dict()
@@ -43,7 +43,7 @@ class ABCSimilaryModel(ABCTaskModel,ABC):
                  max_sequence_length=None):
         """
                         Args:
-                            embedding: embedding object
+                            embedding: encoder object
                             sequence_length: target sequence length
                             hyper_parameters: hyper_parameters to overwrite
                             multi_label: is multi-label classification
@@ -253,7 +253,7 @@ class ABCSimilaryModel(ABCTaskModel,ABC):
                         Args:
                             x_data: The input data, as a Numpy array (or list of Numpy arrays if the model has multiple inputs).
                             batch_size: Integer. If unspecified, it will default to 32.
-                            truncating: remove values from sequences larger than `model.embedding.sequence_length`
+                            truncating: remove values from sequences larger than `model.encoder.sequence_length`
                             multi_label_threshold:
                             predict_kwargs: arguments passed to ``predict()`` function of ``tf.keras.Model``
                         Returns:
