@@ -4,6 +4,13 @@ class ABCTokenizer(ABC):
     """Abstract base class for all implemented tokenizers.
     """
 
+    def __init__(self):
+        self._tokenizer = None
+
+    @property
+    def tokenizer(self):
+        return self._tokenizer
+
     def to_dict(self) -> Dict[str, Any]:
         return {
             '__class_name__': self.__class__.__name__,
