@@ -28,7 +28,7 @@ class HuggingTokenizer(ABCTokenizer):
     def change_model_path(self, new_model_path):
         self.model_path = new_model_path
 
-    def tokenize(self, text, maxlen=None, add_special_tokens=False,**kwargs):
+    def tokenize(self, text, maxlen=None, add_special_tokens=True,**kwargs):
         text = self.tokenizer.tokenize(text,add_special_tokens=add_special_tokens,max_length=maxlen)
         return text
 
